searchData={"items":[{"type":"module","title":"AssertHTML","doc":"AssertHTML provides ExUnit assert helpers for testing rendered HTML using CSS selectors.","ref":"AssertHTML.html"},{"type":"module","title":"Usage in Phoenix Controller and Integration Test - AssertHTML","doc":"Given the `html_response(conn, 200)` returns:\n\n```html\n<!DOCTYPE html>\n \n   \n     PAGE TITLE \n   \n   \n     Sign up \n     Help \n   \n \n```\n\nAn example controller test could be:\n\n```elixir\ndefmodule YourAppWeb.PageControllerTest do\n  use YourAppWeb.ConnCase, async: true\n\n  test \"should get index\", %{conn: conn} do\n    resp_conn = conn\n    |> get(Routes.page_path(conn, :index))\n\n    html_response(conn, 200)\n    # Asserts that the page title is \"PAGE TITLE\"\n    |> assert_html(\"title\", \"PAGE TITLE\")\n    # Asserts that the page title is \"PAGE TITLE\" and there is only one title element\n    |> assert_html(\"title\", count: 1, text: \"PAGE TITLE\")\n    # Asserts that the page title matches \"PAGE\" and there is only one title element\n    |> assert_html(\"title\", count: 1, match: \"PAGE\")\n    # Asserts that the page has one link with href value \"/signup\"\n    |> assert_html(\"a[href='/signup']\", count: 1)\n    # Asserts that the page has at least one link\n    |> assert_html(\"a\", min: 1)\n    # Asserts that the page has at most two links\n    |> assert_html(\"a\", max: 2)\n    # Asserts that the page contains no forms\n    |> refute_html(\"form\")\n  end\nend\n```","ref":"AssertHTML.html#module-usage-in-phoenix-controller-and-integration-test"},{"type":"module","title":"Selector Checks - AssertHTML","doc":"`assert_html(html, \".css .selector .exsits\")` - Asserts that an element exists in the selector path.\n`refute_html(html, \".css .selector\")` - Asserts that an element does not exist in the selector path.","ref":"AssertHTML.html#module-selector-checks"},{"type":"module","title":"Check Attributes - AssertHTML","doc":"Supports meta attributes:\n\n* `:text` – The exact text within the element\n* `:match` - A value that the element's text should contain.","ref":"AssertHTML.html#module-check-attributes"},{"type":"function","title":"AssertHTML.assert_html/2","doc":"Asserts an attributes in HTML element","ref":"AssertHTML.html#assert_html/2"},{"type":"function","title":"Asserting Attributes - AssertHTML.assert_html/2","doc":"- `:text` – Asserts the exact text within an HTML element.\n- `:match` - Asserts that the HTML element's text contains a specific value.\n\n```elixir\niex> html = ~S{    }\n...> assert_html(html, \".zoo\", class: \"bar zoo\")\n~S{    }\n\n# Check if `id` attribute does not exist\niex> assert_html(~S{ text }, id: nil)\n\" text \"\n```\n\n#### Examples for :text\n\nAsserts the exact text within an HTML element.\n\n    iex> html = ~S{ Header }\n    ...> assert_html(html, text: \"Header\")\n    ~S{ Header }\n\n    iex> html = ~S{     Header     }\n    ...> assert_html(html, \".title\", text: \"Header\")\n    ~S{     Header     }\n\n    iex> html = ~S{ Header }\n    ...> try do\n    ...>   assert_html(html, text: \"HEADER\")\n    ...> rescue\n    ...>   e in ExUnit.AssertionError -> e\n    ...> end\n    %ExUnit.AssertionError{\n      left: \"HEADER\",\n      right: \"Header\",\n      message: \"Comparison `text` attribute failed.\\n\\n\\t Header .\\n\"\n    }\n\n    iex> html = ~S{ Some &amp; text }\n    ...> assert_html(html, text: \"Some & text\")\n    ~S{ Some &amp; text }","ref":"AssertHTML.html#assert_html/2-asserting-attributes"},{"type":"function","title":"Selector - AssertHTML.assert_html/2","doc":"`assert_html(html, \"css selector\")`\n\n```elixir\n    iex> html = ~S{   Header   }\n    ...> assert_html(html, \"p .foo h1\")\n    ~S{   Header   }\n\n    iex> html = ~S{   Header   }\n    ...> assert_html(html, \"h1\")\n    ~S{   Header   }\n```","ref":"AssertHTML.html#assert_html/2-selector"},{"type":"function","title":"Match elements in HTML - AssertHTML.assert_html/2","doc":"Asserts that the HTML contains a specific element.\n\n```elixir\n    assert_html(html, ~r{ Hello })\n    assert_html(html, match: ~r{ Hello })\n    assert_html(html, match: \" Hello \")\n```","ref":"AssertHTML.html#assert_html/2-match-elements-in-html"},{"type":"function","title":"Asserts a text element in HTML - AssertHTML.assert_html/2","doc":"iex> html = ~S{   Header   }\n    ...> assert_html(html, \"p .foo h1\", text: \"Header\")\n    ~S{   Header   }","ref":"AssertHTML.html#assert_html/2-asserts-a-text-element-in-html"},{"type":"function","title":"Examples - AssertHTML.assert_html/2","doc":"iex> html = ~S{     Hello World     }\n    ...> assert_html(html, \"h1\", \"Hello World\") == html\n    true\n\n    iex> html = ~S{     Hello World     }\n    ...> assert_html(html, \".title\", ~r{World})\n    ~S{     Hello World     }","ref":"AssertHTML.html#assert_html/2-examples"},{"type":"function","title":"assert elements in selector - AssertHTML.assert_html/2","doc":"assert_html(html, \".container table\", ~r{ Hello })","ref":"AssertHTML.html#assert_html/2-assert-elements-in-selector"},{"type":"function","title":"AssertHTML.assert_html/3","doc":"","ref":"AssertHTML.html#assert_html/3"},{"type":"function","title":"AssertHTML.assert_html/4","doc":"","ref":"AssertHTML.html#assert_html/4"},{"type":"type","title":"AssertHTML.attribute_name/0","doc":"HTML element attribute name","ref":"AssertHTML.html#t:attribute_name/0"},{"type":"type","title":"AssertHTML.attributes/0","doc":"HTML element attributes","ref":"AssertHTML.html#t:attributes/0"},{"type":"type","title":"AssertHTML.context/0","doc":"","ref":"AssertHTML.html#t:context/0"},{"type":"type","title":"AssertHTML.css_selector/0","doc":"CSS selector","ref":"AssertHTML.html#t:css_selector/0"},{"type":"type","title":"Supported selectors - AssertHTML.css_selector/0","doc":"| Pattern         | Description                  |\n|-----------------|------------------------------|\n| *               | any element                  |\n| E               | an element of type `E`       |\n| E[foo]          | an `E` element with a \"foo\" attribute |\n| E[foo=\"bar\"]    | an E element whose \"foo\" attribute value is exactly equal to \"bar\" |\n| E[foo~=\"bar\"]   | an E element whose \"foo\" attribute value is a list of whitespace-separated values, one of which is exactly equal to \"bar\" |\n| E[foo^=\"bar\"]   | an E element whose \"foo\" attribute value begins exactly with the string \"bar\" |\n| E[foo$=\"bar\"]   | an E element whose \"foo\" attribute value ends exactly with the string \"bar\" |\n| E[foo*=\"bar\"]   | an E element whose \"foo\" attribute value contains the substring \"bar\" |\n| E[foo\\|=\"en\"]    | an E element whose \"foo\" attribute has a hyphen-separated list of values beginning (from the left) with \"en\" |\n| E:nth-child(n)  | an E element, the n-th child of its parent |\n| E:first-child   | an E element, first child of its parent |\n| E:last-child   | an E element, last child of its parent |\n| E:nth-of-type(n)  | an E element, the n-th child of its type among its siblings |\n| E:first-of-type   | an E element, first child of its type among its siblings |\n| E:last-of-type   | an E element, last child of its type among its siblings |\n| E.warning       | an E element whose class is \"warning\" |\n| E#myid          | an `E` element with ID equal to \"myid\" |\n| E:not(s)        | an E element that does not match simple selector s |\n| E F             | an F element descendant of an E element |\n| E > F           | an F element child of an E element |\n| E + F           | an F element immediately preceded by an E element |\n| E ~ F           | an F element preceded by an E element |","ref":"AssertHTML.html#t:css_selector/0-supported-selectors"},{"type":"type","title":"AssertHTML.html/0","doc":"HTML response","ref":"AssertHTML.html#t:html/0"},{"type":"function","title":"AssertHTML.refute_html/2","doc":"Opposite method for assert_html\n\nSee more (t:refute_html/2)","ref":"AssertHTML.html#refute_html/2"},{"type":"function","title":"AssertHTML.refute_html/3","doc":"","ref":"AssertHTML.html#refute_html/3"},{"type":"function","title":"AssertHTML.refute_html/4","doc":"","ref":"AssertHTML.html#refute_html/4"},{"type":"type","title":"AssertHTML.value/0","doc":"Checking value\n- if nil should not exist","ref":"AssertHTML.html#t:value/0"},{"type":"module","title":"AssertHTML.DSL","doc":"Add aditional syntax to passing current context inside block","ref":"AssertHTML.DSL.html"},{"type":"module","title":"Example: pass context - AssertHTML.DSL","doc":"```\nassert_html html, \".container\" do\n  assert_html \"form\", action: \"/users\" do\n    refute_html \".flash_message\"\n    assert_html \".control_group\" do\n      assert_html \"label\", class: \"title\", text: ~r{Full name}\n      assert_html \"input\", class: \"control\", type: \"text\"\n    end\n    assert_html(\"a\", text: \"Submit\", class: \"button\")\n  end\n  assert_html \".user_list\" do\n    assert_html \"li\"\n  end\nend\n```","ref":"AssertHTML.DSL.html#module-example-pass-context"},{"type":"module","title":"Example 2: print current context for debug - AssertHTML.DSL","doc":"```\nassert_html(html, \".selector\") do\n  IO.inspect(assert_html, label: \"current context html\")\nend\n```","ref":"AssertHTML.DSL.html#module-example-2-print-current-context-for-debug"},{"type":"macro","title":"AssertHTML.DSL.assert_html/4","doc":"","ref":"AssertHTML.DSL.html#assert_html/4"},{"type":"macro","title":"AssertHTML.DSL.refute_html/4","doc":"","ref":"AssertHTML.DSL.html#refute_html/4"},{"type":"extras","title":"AssertHTML: Elixir Library for testing HTML and XML using CSS selectors","doc":"# AssertHTML: Elixir Library for testing HTML and XML using CSS selectors\n\n[![Build Status](https://travis-ci.org/Kr00lIX/assert_html.svg?branch=master)](https://travis-ci.org/Kr00lIX/assert_html)\n[![Hex pm](https://img.shields.io/hexpm/v/assert_html.svg?style=flat)](https://hex.pm/packages/assert_html)\n[![Coverage Status](https://coveralls.io/repos/github/Kr00lIX/assert_html/badge.svg?branch=master)](https://coveralls.io/github/Kr00lIX/assert_html?branch=master)\n \nAssertHTML is a powerful Elixir library designed for parsing and extracting data from HTML and XML using CSS. It also provides ExUnit assert helpers for testing rendered HTML using CSS selectors, making it an essential tool for Phoenix Controller and Integration tests.","ref":"readme.html"},{"type":"extras","title":"Features - AssertHTML: Elixir Library for testing HTML and XML using CSS selectors","doc":"- **HTML and XML Parsing**: Easily parse and extract data from HTML and XML documents.\n- **CSS Selectors**: Use CSS selectors to find and manipulate elements in your HTML or XML.\n- **ExUnit Assert Helpers**: Test your rendered HTML with the help of ExUnit assert helpers.","ref":"readme.html#features"},{"type":"extras","title":"Getting Started - AssertHTML: Elixir Library for testing HTML and XML using CSS selectors","doc":"Follow these steps to get started with AssertHTML:\n\n1. **Install the Library**: Add `assert_html` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:assert_html, \"~> 0.1\"}\n  ]\nend\n```\n\nThen run `mix deps.get` to fetch the dependency.\n\n2. **Import formating**: Update your .formatter.exs file with the following import:\n\n```elixir\n[\n  import_deps: [\n    :assert_html\n  ]\n]\n```\n\n3. **Add the Library to your Test**: Add `AssertHTML` to your test file:\n\n```elixir\nuse AssertHTML\n```","ref":"readme.html#getting-started"},{"type":"extras","title":"Usage - AssertHTML: Elixir Library for testing HTML and XML using CSS selectors","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Usage in Phoenix Controller and Integration Test - AssertHTML: Elixir Library for testing HTML and XML using CSS selectors","doc":"Assuming the `html_response(conn, 200)` returns:\n\n```html\n<!DOCTYPE html>\n \n   \n     PAGE TITLE \n   \n   \n     Sign up \n     Help \n   \n \n```\n\nAn example controller test:\n\n```elixir\ndefmodule YourAppWeb.PageControllerTest do\n  use YourAppWeb.ConnCase, async: true\n\n  test \"should get index\", %{conn: conn} do        \n    resp_conn = conn\n    |> get(Routes.page_path(conn, :index))\n\n    html_response(resp_conn, 200)\n    # The page title is \"PAGE TITLE\"\n    |> assert_html(\"title\", \"PAGE TITLE\")\n    # The page title is \"PAGE TITLE\", and there is only one title element\n    |> assert_html(\"title\", count: 1, text: \"PAGE TITLE\")\n    # The page title matches \"PAGE\", and there is only one title element\n    |> assert_html(\"title\", count: 1, match: \"PAGE\")\n    # The page has one link with the href value \"/signup\"\n    |> assert_html(\"a[href='/signup']\", count: 1)\n    # The page has at least one link\n    |> assert_html(\"a\", min: 1)\n    # The page has at most two links\n    |> assert_html(\"a\", max: 2)\n    # The page contains no forms\n    |> refute_html(\"form\")\n  end\nend\n```","ref":"readme.html#usage-in-phoenix-controller-and-integration-test"},{"type":"extras","title":"Contains - AssertHTML: Elixir Library for testing HTML and XML using CSS selectors","doc":"`assert_html(html, ~r{Hello World})` - match string in HTML  \n`refute_html(html, ~r{Another World})` - should not contain string in HTML\n\n```elixir\nassert_html(html, \".content\") do\n  assert_html(~r{Hello World})\nend\n```","ref":"readme.html#contains"},{"type":"extras","title":"CSS selectors - AssertHTML: Elixir Library for testing HTML and XML using CSS selectors","doc":"`assert_html(html, \".css .selector\")` - checks if an element exists in the CSS selector path\n`refute_html(html, \".errors .error\")` - checks if an element does not exist in the path","ref":"readme.html#css-selectors"},{"type":"extras","title":"Check attributes - AssertHTML: Elixir Library for testing HTML and XML using CSS selectors","doc":"```elixir\nassert_html(html, \"form\", class: \"form\", method: \"post\", action: \"/session/login\") do\n  assert_html \".-email\" do\n    assert_html(\"label\", text: \"Email\", for: \"staticEmail\", class: \"col-form-label\")\n    assert_html(\"div input\", type: \"text\", readonly: true, class: \"form-control-plaintext\", value: \"email@example.com\")\n  end\n  assert_html(\".-password\") do\n    assert_html(\"label\", text: \"Password\", for: \"inputPassword\")\n    assert_html(\"div input\", placeholder: \"Password\", type: \"password\", class: \"form-control\", id: \"inputPassword\")\n  end\n\n  assert_html(\"button\", type: \"submit\", class: \"primary\")\nend\n```","ref":"readme.html#check-attributes"},{"type":"extras","title":"Example - AssertHTML: Elixir Library for testing HTML and XML using CSS selectors","doc":"```elixir\ndefmodule ExampleControllerTest do\n  use ExUnit.Case, async: true\n  use AssertHTML\n\n  test \"shows search form\", %{conn: conn} do\n    conn_resp = get(conn, Routes.page_path(conn, :new))\n    assert response = html_response(conn_resp, 200)\n\n    assert_html response do\n      # Check if element exists in CSS selector path\n      assert_html \"p.description\"\n\n      # Check if element doesn't exist\n      refute_html \".flash-message\"\n\n      # Assert form attributes\n      assert_html \"form.new_page\", action: Routes.page_path(conn, :create), method: \"post\" do\n        # Assert elements inside the `form.new_page` selector\n        assert_html \"label\", class: \"form-label\", text: \"Page name\"\n        assert_html \"input\", type: \"text\", class: \"form-control\", value: \"\", name: \"page_name\"\n        assert_html \"button\", class: \"form-button\", text: \"Submit\"\n      end\n    end\n  end\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/assert_html](https://hexdocs.pm/assert_html/AssertHTML.html).","ref":"readme.html#example"},{"type":"extras","title":"Contribution - AssertHTML: Elixir Library for testing HTML and XML using CSS selectors","doc":"Feel free to send your PR with proposals, improvements or corrections 😉.","ref":"readme.html#contribution"},{"type":"extras","title":"Author - AssertHTML: Elixir Library for testing HTML and XML using CSS selectors","doc":"Anatolii Kovalchuk (@Kr00liX)","ref":"readme.html#author"},{"type":"extras","title":"License - AssertHTML: Elixir Library for testing HTML and XML using CSS selectors","doc":"This software is licensed under [the MIT license](LICENSE.md).","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Changelog","doc":"","ref":"changelog.html#unreleased"},{"type":"extras","title":"v0.0.4 - Changelog","doc":"","ref":"changelog.html#v0-0-4"},{"type":"extras","title":"Fixed - Changelog","doc":"- refute attributes","ref":"changelog.html#fixed"},{"type":"extras","title":"v0.0.3 - Changelog","doc":"","ref":"changelog.html#v0-0-3"},{"type":"extras","title":"Fixed - Changelog","doc":"- Checking attributes with non sting values\n- Check no existing attributes `attribute_name: nil`","ref":"changelog.html#fixed-1"},{"type":"extras","title":"Added - Changelog","doc":"- add `assert_html match: \"value\"` checker  \n- Add `assert_html_contains(html, value)` and `refute_html_contains(html, value)` checkers\n- Add `assert_html` macro for simplify DSL\n  ```\n  use AssertHTML\n\n  test \"shows new page form\", %{conn: conn} do\n      conn_resp = get(conn, Routes.page_path(conn, :new))\n      assert response = html_response(conn_resp, 200)\n\n      assert_html(response) do\n        assert_html(\"title\", \"New page\")\n        assert_html(\"p.description\", ~r{You can check text by regular expression})\n        refute_html(\".check .element .if_doesnt_exist\")\n        assert_html(\"form.new_page\", action: Routes.page_path(conn, :create), method: \"post\") do\n          assert_html(\".control_group\") do\n              assert_html(\"label\", class: \"form-label\", text: \"Page name\")\n              assert_html(\"input\", type: \"text\", class: \"form-control\", value: \"\", name: \"page[name]\")\n            end\n            assert_html(\"button\", class: \"form-button\", text: \"Submit\")\n          end\n        end\n      end\n    end\n  ```","ref":"changelog.html#added"},{"type":"extras","title":"Deleted - Changelog","doc":"- Delete `assert_html_contains(html, \"text\")` -> use `assert_html(html, ~r\"text\")` instead\n- Delete `refute_html_contains(html, \"text\")` -> use `refute_html(html, ~r\"text\")` instead\n- Delete `refute_html_selector(html, selector)` (use `refute_html(html, selector)` instead)","ref":"changelog.html#deleted"},{"type":"extras","title":"v0.0.1 - Changelog","doc":"","ref":"changelog.html#v0-0-1"},{"type":"extras","title":"Added - Changelog","doc":"- Allow use Regexp for checking attribute value\n- Add `assert_attributes(html, selector, [id: \"name\"], fn(sub_html)->   end)` callback with selected html\n- Add `assert_attributes(html, selector, id: \"name\")` checker\n- Add `assert_html_selector(html, css_selector)` and `refute_html_selector((html, css_selector, value)` checkers\n- Add `assert_html_text(html, value)` and `assert_html_text(html, css_selector, value)` checkers\n- Add `refute_html_text(html, value)` and `refute_html_text((html, css_selector, value)` checkers\n- Add `html_selector(html, css_selector)` method\n- Add `html_attribute(html, css_selector)` and `html_attribute(html, css_selector, name)`  methods\n- Add `html_text(html, css_selector)` method\n- Basic ExDoc configuration\n- Markdown documentation (README, LICENSE, CHANGELOG)","ref":"changelog.html#added-1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}